summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kmymoneyview.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 06:08:18 +0000
commit7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (patch)
tree6a288b084438ed144c0fbd4a34a9a22caf4d6b04 /kmymoney2/views/kmymoneyview.cpp
parent154e6e6105157c321cbd578d238c525da419f868 (diff)
downloadkmymoney-7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2.tar.gz
kmymoney-7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246075 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/views/kmymoneyview.cpp')
-rw-r--r--kmymoney2/views/kmymoneyview.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kmymoney2/views/kmymoneyview.cpp b/kmymoney2/views/kmymoneyview.cpp
index 8d7aa4d..2c3a10d 100644
--- a/kmymoney2/views/kmymoneyview.cpp
+++ b/kmymoney2/views/kmymoneyview.cpp
@@ -1688,7 +1688,7 @@ void KMyMoneyView::fixFile_2(void)
void KMyMoneyView::fixFile_1(void)
{
// we need to fix reports. If the account filter list tqcontains
// investment accounts, we need to add the stock accounts to the list
// as well if we don't have the expert mode enabled
if(!KMyMoneyGlobalSettings::expertMode()) {
@@ -1704,7 +1704,7 @@ void KMyMoneyView::fixFile_1(void)
MyMoneyAccount acc = MyMoneyFile::instance()->account(*it_a);
if(acc.accountType() == MyMoneyAccount::Investment) {
for(it_b = acc.accountList().begin(); it_b != acc.accountList().end(); ++it_b) {
- if(!list.tqcontains(*it_b)) {
+ if(!list.contains(*it_b)) {
missing.append(*it_b);
}
}
@@ -1737,7 +1737,7 @@ void KMyMoneyView::fixFile_1(void)
MyMoneyAccount acc = MyMoneyFile::instance()->account(*it_a);
if(acc.accountType() == MyMoneyAccount::Investment) {
for(it_b = acc.accountList().begin(); it_b != acc.accountList().end(); ++it_b) {
- if(!list.tqcontains(*it_b)) {
+ if(!list.contains(*it_b)) {
missing.append(*it_b);
}
}
@@ -1975,7 +1975,7 @@ void KMyMoneyView::fixTransactions_0(void)
bool hasDuplicateAccounts = false;
for(it_s = t.splits().begin(); it_s != t.splits().end(); ++it_s) {
- if(accounts.tqcontains((*it_s).accountId())) {
+ if(accounts.contains((*it_s).accountId())) {
hasDuplicateAccounts = true;
kdDebug(2) << __func__ << " " << t.id() << " has multiple splits with account " << (*it_s).accountId() << endl;
} else {
@@ -1983,7 +1983,7 @@ void KMyMoneyView::fixTransactions_0(void)
}
if((*it_s).action() == MyMoneySplit::ActionInterest) {
- if(interestAccounts.tqcontains((*it_s).accountId()) == 0) {
+ if(interestAccounts.contains((*it_s).accountId()) == 0) {
interestAccounts << (*it_s).accountId();
}
}
@@ -2091,14 +2091,14 @@ void KMyMoneyView::fixTransactions_0(void)
// and check if there are any duplicates in this transactions
for(it_s = splits.begin(); it_s != splits.end(); ++it_s) {
MyMoneyAccount splitAccount = file->account((*it_s).accountId());
- if(accounts.tqcontains((*it_s).accountId())) {
+ if(accounts.contains((*it_s).accountId())) {
hasDuplicateAccounts = true;
} else {
accounts << (*it_s).accountId();
}
// if this split references an interest account, the action
// must be of type ActionInterest
- if(interestAccounts.tqcontains((*it_s).accountId())) {
+ if(interestAccounts.contains((*it_s).accountId())) {
if((*it_s).action() != MyMoneySplit::ActionInterest) {
kdDebug(2) << __func__ << " " << (*it_t).id() << " contains an interest account (" << (*it_s).accountId() << ") but does not have ActionInterest" << endl;
(*it_s).setAction(MyMoneySplit::ActionInterest);
@@ -1688,7 +1688,7 @@ void KMyMoneyView::fixFile_2(void)
void KMyMoneyView::fixFile_1(void)
{
- // we need to fix reports. If the account filter list tqcontains
+ // we need to fix reports. If the account filter list contains
// investment accounts, we need to add the stock accounts to the list
// as well if we don't have the expert mode enabled